==> zio-aws-databasemigration_2.12-5.17.124.1-sources.jar: zio/aws/databasemigration/model/DescribeEndpointSettingsRequest.scala <==
package zio.aws.databasemigration.model
import java.lang.Integer
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.aws.databasemigration.model.primitives.IntegerOptional
import scala.jdk.CollectionConverters._
final case class DescribeEndpointSettingsRequest(
    engineName: String,
    maxRecords: Option[IntegerOptional] = None,
    marker: Option[String] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.databasemigration.model.DescribeEndpointSettingsRequest = {
    import DescribeEndpointSettingsRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.databasemigration.model.DescribeEndpointSettingsRequest
      .builder()
      .engineName(engineName: java.lang.String)
      .optionallyWith(
        maxRecords.map(value => IntegerOptional.unwrap(value): Integer)
      )(_.maxRecords)
      .optionallyWith(marker.map(value => value: java.lang.String))(_.marker)
      .build()
  }
  def asReadOnly
      : zio.aws.databasemigration.model.DescribeEndpointSettingsRequest.ReadOnly =
    zio.aws.databasemigration.model.DescribeEndpointSettingsRequest
      .wrap(buildAwsValue())
}
object DescribeEndpointSettingsRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.databasemigration.model.DescribeEndpointSettingsRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable
        : zio.aws.databasemigration.model.DescribeEndpointSettingsRequest =
      zio.aws.databasemigration.model.DescribeEndpointSettingsRequest(
        engineName,
        maxRecords.map(value => value),
        marker.map(value => value)
      )
    def engineName: String
    def maxRecords: Option[IntegerOptional]
    def marker: Option[String]
    def getEngineName: ZIO[Any, Nothing, String] = ZIO.succeed(engineName)
    def getMaxRecords: ZIO[Any, AwsError, IntegerOptional] =
      AwsError.unwrapOptionField("maxRecords", maxRecords)
    def getMarker: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField("marker", marker)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.databasemigration.model.DescribeEndpointSettingsRequest
  ) extends zio.aws.databasemigration.model.DescribeEndpointSettingsRequest.ReadOnly {
    override val engineName: String = impl.engineName(): String
    override val maxRecords: Option[IntegerOptional] = scala
      .Option(impl.maxRecords())
      .map(value =>
        zio.aws.databasemigration.model.primitives.IntegerOptional(value)
      )
    override val marker: Option[String] =
      scala.Option(impl.marker()).map(value => value: String)
  }
  def wrap(
      impl: software.amazon.awssdk.services.databasemigration.model.DescribeEndpointSettingsRequest
  ): zio.aws.databasemigration.model.DescribeEndpointSettingsRequest.ReadOnly =
    new Wrapper(impl)
}

==> zio-aws-databasemigration_2.12-5.17.158.4-sources.jar: zio/aws/databasemigration/model/DescribeEndpointSettingsRequest.scala <==
package zio.aws.databasemigration.model
import java.lang.Integer
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.aws.databasemigration.model.primitives.IntegerOptional
import scala.jdk.CollectionConverters._
final case class DescribeEndpointSettingsRequest(
    engineName: String,
    maxRecords: Option[IntegerOptional] = None,
    marker: Option[String] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.databasemigration.model.DescribeEndpointSettingsRequest = {
    import DescribeEndpointSettingsRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.databasemigration.model.DescribeEndpointSettingsRequest
      .builder()
      .engineName(engineName: java.lang.String)
      .optionallyWith(maxRecords.map(value => value: Integer))(_.maxRecords)
      .optionallyWith(marker.map(value => value: java.lang.String))(_.marker)
      .build()
  }
  def asReadOnly
      : zio.aws.databasemigration.model.DescribeEndpointSettingsRequest.ReadOnly =
    zio.aws.databasemigration.model.DescribeEndpointSettingsRequest
      .wrap(buildAwsValue())
}
object DescribeEndpointSettingsRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.databasemigration.model.DescribeEndpointSettingsRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable
        : zio.aws.databasemigration.model.DescribeEndpointSettingsRequest =
      zio.aws.databasemigration.model.DescribeEndpointSettingsRequest(
        engineName,
        maxRecords.map(value => value),
        marker.map(value => value)
      )
    def engineName: String
    def maxRecords: Option[IntegerOptional]
    def marker: Option[String]
    def getEngineName: ZIO[Any, Nothing, String] = ZIO.succeed(engineName)
    def getMaxRecords: ZIO[Any, AwsError, IntegerOptional] =
      AwsError.unwrapOptionField("maxRecords", maxRecords)
    def getMarker: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField("marker", marker)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.databasemigration.model.DescribeEndpointSettingsRequest
  ) extends zio.aws.databasemigration.model.DescribeEndpointSettingsRequest.ReadOnly {
    override val engineName: String = impl.engineName(): String
    override val maxRecords: Option[IntegerOptional] =
      scala.Option(impl.maxRecords()).map(value => value: IntegerOptional)
    override val marker: Option[String] =
      scala.Option(impl.marker()).map(value => value: String)
  }
  def wrap(
      impl: software.amazon.awssdk.services.databasemigration.model.DescribeEndpointSettingsRequest
  ): zio.aws.databasemigration.model.DescribeEndpointSettingsRequest.ReadOnly =
    new Wrapper(impl)
}
